┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinview.h
diff options
context:
space:
mode:
authorKevin Ottens <[email protected]>2007-04-02 19:20:07 +0000
committerKevin Ottens <[email protected]>2007-04-02 19:20:07 +0000
commit03713b0ab408a42a20c9ce6a51d069b3246d2502 (patch)
tree1aff603918b502ae1927b74b5b668e4659268f51 /src/dolphinview.h
parent78c312a0f33b15b34aed8ea7cf9e9c344dea1f87 (diff)
Rename all the URL navigator related classes to prepare their migration
in kdelibs. svn path=/trunk/KDE/kdebase/apps/; revision=649514
Diffstat (limited to 'src/dolphinview.h')
-rw-r--r--src/dolphinview.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/dolphinview.h b/src/dolphinview.h
index d9a241759..2118aaf56 100644
--- a/src/dolphinview.h
+++ b/src/dolphinview.h
@@ -27,7 +27,7 @@
#include <kfileitemdelegate.h>
#include <kio/job.h>
-#include <urlnavigator.h>
+#include <kurlnavigator.h>
#include <QDropEvent>
#include <QLinkedList>
@@ -41,7 +41,7 @@ class FilterBar;
class KFileItemDelegate;
class KUrl;
class KDirModel;
-class UrlNavigator;
+class KUrlNavigator;
class DolphinColumnView;
class DolphinDetailsView;
class DolphinDirLister;
@@ -64,7 +64,7 @@ class ViewProperties;
* @see DolphinIconsView
* @see DolphinDetailsView
* @see DolphinColumnView
- * @see UrlNavigator
+ * @see KUrlNavigator
* @see DolphinStatusBar
*/
class DolphinView : public QWidget
@@ -121,7 +121,7 @@ public:
/**
* Sets the current active URL.
* The signals UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
* are emitted.
*/
void setUrl(const KUrl& url);
@@ -185,28 +185,28 @@ public:
/**
* Goes back one step in the URL history. The signals
* UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
* are submitted.
*/
void goBack();
/**
* Goes forward one step in the Url history. The signals
* UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
* are submitted.
*/
void goForward();
/**
* Goes up one step of the Url path. The signals
* UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
* are submitted.
*/
void goUp();
/**
* Goes to the home URL. The signals UrlNavigator::urlChanged()
* and UrlNavigator::historyChanged() are submitted.
*/
void goHome();
@@ -266,7 +266,7 @@ public:
/**
* Returns true, if the URL shown by the navigation bar is editable.
- * @see UrlNavigator
+ * @see KUrlNavigator
*/
bool isUrlEditable() const;
@@ -306,8 +306,8 @@ public:
/** Returns the additional information which should be shown for the items. */
KFileItemDelegate::AdditionalInformation additionalInfo() const;
- /** Returns the UrlNavigator of the view for read access. */
- const UrlNavigator* urlNavigator() const { return m_urlNavigator; }
+ /** Returns the KUrlNavigator of the view for read access. */
+ const KUrlNavigator* urlNavigator() const { return m_urlNavigator; }
/**
* Triggers to request user information for the item given
@@ -572,7 +572,7 @@ private:
DolphinMainWindow* m_mainWindow;
QVBoxLayout* m_topLayout;
- UrlNavigator* m_urlNavigator;
+ KUrlNavigator* m_urlNavigator;
DolphinController* m_controller;
DolphinIconsView* m_iconsView;
@@ -121,7 +121,7 @@ public:
/**
* Sets the current active URL.
- * The signals UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
+ * The signals KUrlNavigator::urlChanged() and KUrlNavigator::historyChanged()
* are emitted.
*/
@@ -185,28 +185,28 @@ public:
/**
* Goes back one step in the URL history. The signals
- * UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
+ * KUrlNavigator::urlChanged() and KUrlNavigator::historyChanged()
* are submitted.
*/
@@ -185,28 +185,28 @@ public:
/**
* Goes forward one step in the Url history. The signals
- * UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
+ * KUrlNavigator::urlChanged() and KUrlNavigator::historyChanged()
* are submitted.
*/
@@ -185,28 +185,28 @@ public:
/**
* Goes up one step of the Url path. The signals
- * UrlNavigator::urlChanged() and UrlNavigator::historyChanged()
+ * KUrlNavigator::urlChanged() and KUrlNavigator::historyChanged()
* are submitted.
*/
@@ -185,28 +185,28 @@ public:
void goUp();
/**
- * Goes to the home URL. The signals UrlNavigator::urlChanged()
- * and UrlNavigator::historyChanged() are submitted.
+ * Goes to the home URL. The signals KUrlNavigator::urlChanged()
+ * and KUrlNavigator::historyChanged() are submitted.
*/
void goHome();